==> leadconduit-integration-leadconduit-1.2.0.tgz: package/lib/ui/public/app/config/index.js <==
var ui = require('leadconduit-integration-ui');
var { cleanParams } = require('./helpers/scrubber');
var _ = require('lodash');

module.exports = function(app, config) {
  app.
    controller('ConfigViewCtrl', ['$scope', '$http', function($scope, $http) {
      $scope.cancel = function() {
        ui.cancel();
      };

      // initialize object to return to LC
      $scope.flow = {
        fields: [],
        steps: [{
          type: 'recipient',
          entity: {
            name: config.entity.name,
            id: config.entity.id
          },
          integration: {
            module_id: config.integration || 'leadconduit-integration-leadconduit.outbound.to_flow',
            mappings: []
          }
        }]
      };

      // initialize data structure for rich UI use
      $scope.state = {
        loading: true,
        flows: [],
        selectedFlow: {},
        fields: [],
        account_name: config.entity.name
      };
    }])

    .controller('Page1Ctrl', ['$scope', '$http', function($scope, $http) {
      // reset state, in case user has come back here from Next screen
      var entityId = config.entity.id;
      var apiKey = config.credential.token;

      $http.get('entities', {params: {entityId, apiKey}})
        .then(function(response) {
          // ensure current flow isn't listed as a destination
          var flowIds = _.filter(response.data.flow_ids, function(flow_id) { return flow_id !== config.flow.id });
          flowPromises = flowIds.map(function(flowId) {
            return $http.get('flows/meta', {params: {flowId, sourceId: config.accountInfo.id}});
          });
          Promise.all(flowPromises)
            .then(function(flows) {
              // remove all 'not found' responses
              flows = _.filter(flows,function(flow) {return (_.get(flow, 'data.params') && config.entity.id === _.get(flow, 'data.account.id'))});
              $scope.state.flows = (flows) ? flows.map(function(flow) {return cleanParams(flow.data)}) : [];
              $scope.state.loading = false;
              $scope.$apply();
            })
        });

      if(!$scope.state.fields.length) {
        $http.get('flows', { params: {flowId: config.flow.id, apiKey}})
          .then(function(response) {
            $scope.state.fields = response.data.fields.map(function(field) { return { "name": field, "required": false }});
          });
      }

      $scope.finish = function() {

        var uniqueFields = _.differenceBy($scope.state.selectedFlow.params, $scope.state.fields, 'name')
          .map(function(field) { return { "name": `custom.${field.name}`, "required": field.required }});

        $scope.flow.fields = uniqueFields;
        $scope.flow.steps[0].integration.mappings.push({property: 'flow_id', value: $scope.state.selectedFlow.flow.id});

        ui.create({
          flow: $scope.flow,
        });
      };
    }]);
};

==> leadconduit-integration-leadconduit-1.2.7.tgz: package/lib/ui/public/app/config/index.js <==
var ui = require('leadconduit-integration-ui');
var { cleanParams } = require('./helpers/scrubber');
var _ = require('lodash');

module.exports = function(app, config) {
  app.
    controller('ConfigViewCtrl', ['$scope', '$http', function($scope, $http) {
      $scope.cancel = function() {
        ui.cancel();
      };

      // initialize object to return to LC
      $scope.flow = {
        fields: [],
        steps: [{
          type: 'recipient',
          entity: {
            name: config.entity.name,
            id: config.entity.id
          },
          integration: {
            module_id: config.integration || 'leadconduit-integration-leadconduit.outbound.to_flow',
            mappings: []
          }
        }]
      };

      // initialize data structure for rich UI use
      $scope.state = {
        loading: true,
        flows: [],
        selectedFlow: {},
        fields: [],
        accountName: config.entity.name,
        isSameAccount: config.entity.id === config.accountInfo.id
      };

      switch(config.env) {
        case 'production': $scope.baseUrl = 'https://next.leadconduit.com';
          break;
        case 'staging': $scope.baseUrl  = 'https://next.staging.leadconduit.com';
          break;
        case 'development': $scope.baseUrl = 'http://leadconduit.localhost';
      }
    }])

    .controller('Page1Ctrl', ['$scope', '$http', function($scope, $http) {
      // reset state, in case user has come back here from Next screen
      var entityId = config.entity.id;
      var apiKey = config.credential.token;

      $http.get('entities', {params: {entityId, apiKey, baseUrl: $scope.baseUrl}})
        .then(function(response) {
          // ensure current flow isn't listed as a destination
          var flowIds = _.filter(response.data.flow_ids, function(flow_id) { return flow_id !== config.flow.id });
          flowPromises = flowIds.map(function(flowId) {
            return $http.get('flows/meta', {params: {flowId, sourceId: config.accountInfo.id, baseUrl: $scope.baseUrl}});
          });
          Promise.all(flowPromises)
            .then(function(flows) {
              // remove all 'not found' responses
              flows = _.filter(flows,function(flow) {return (_.get(flow, 'data.params') && config.entity.id === _.get(flow, 'data.account.id'))});
              $scope.state.flows = (flows) ? flows.map(function(flow) {return cleanParams(flow.data)}) : [];
              $scope.state.flows = _.sortBy($scope.state.flows, function(flow) {return flow.flow.name.toLowerCase()});

              // if there's only one option select that by default
              if($scope.state.flows.length === 1) $scope.state.selectedFlow = $scope.state.flows[0];

              $scope.state.loading = false;
              $scope.$apply();
            })
        });

      if(!$scope.state.fields.length) {
        if(_.get(config, 'flow.fields')) {
          $scope.state.fields = config.flow.fields.map(function(field) {
            return { "name": field.value, "required": false }
          });
        }
        else {
          $http.get('flows', {params: {flowId: config.flow.id, apiKey, baseUrl: $scope.baseUrl}})
            .then(function (response) {
              $scope.state.fields = response.data.fields.map(function (field) {
                return {"name": field, "required": false}
              });
            });
        }
      }

      $scope.finish = function() {

        var uniqueFields = _.differenceBy($scope.state.selectedFlow.params, $scope.state.fields, 'name')
          .map(function(field) { return { "name": `custom.${field.name}`, "required": field.required }});

        $scope.flow.fields = uniqueFields;
        $scope.flow.steps[0].integration.mappings.push({property: 'flow_id', value: $scope.state.selectedFlow.flow.id});

        ui.create({
          flow: $scope.flow,
        });
      };
    }]);
};
